/******************************************************************************
 * OpenLP - Open Source Lyrics Projection                                      *
 * --------------------------------------------------------------------------- *
 * Copyright (c) 2011-2014 Raoul Snyman                                        *
 * Portions copyright (c) 2011-2014 Tim Bentley, Johan Mynhardt                *
 *                                                                             *
 * --------------------------------------------------------------------------- *
 * This program is free software; you can redistribute it and/or modify it     *
 * under the terms of the GNU General Public License as published by the Free  *
 * Software Foundation; version 2 of the License.                              *
 *                                                                             *
 * This program is distributed in the hope that it will be useful, but WITHOUT *
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       *
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    *
 * more details.                                                               *
 *                                                                             *
 * You should have received a copy of the GNU General Public License along     *
 * with this program; if not, write to the Free Software Foundation, Inc., 59  *
 * Temple Place, Suite 330, Boston, MA 02111-1307 USA                          *
 *******************************************************************************/
package org.openlp.android2;

import android.app.Activity;
import android.app.ActionBar;
import android.app.FragmentManager;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.support.v4.widget.DrawerLayout;
import org.openlp.android2.activities.ConnectionActivity;
import org.openlp.android2.activities.SettingsActivity;
import org.openlp.android2.common.NavigationOptions;
import org.openlp.android2.dialogs.AlertDisplayDialog;
import org.openlp.android2.dialogs.BlankDisplayDialog;
import org.openlp.android2.fragments.*;


public class OpenLP extends Activity
        implements NavigationDrawerFragment.NavigationDrawerCallbacks {

    /**
     * Fragment managing the behaviors, interactions and presentation of the navigation drawer.
     */
    private NavigationDrawerFragment mNavigationDrawerFragment;

    /**
     * Used to store the last screen title. For use in {@link #restoreActionBar()}.
     */
    private CharSequence mTitle;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_open_lp);

        mNavigationDrawerFragment = (NavigationDrawerFragment)
                getFragmentManager().findFragmentById(R.id.navigation_drawer);
        mTitle = getTitle();

        // Set up the drawer.
        mNavigationDrawerFragment.setUp(
                R.id.navigation_drawer,
                (DrawerLayout) findViewById(R.id.drawer_layout));
    }

    @Override
    public void onNavigationDrawerItemSelected(int position) {
        // update the main content by replacing fragments
        FragmentManager fragmentManager = getFragmentManager();
        switch (position) {
            case NavigationOptions.Home:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, HomeFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.home);
                break;
            case NavigationOptions.ServiceList:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, ServiceListFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.service_list);
                break;
            case NavigationOptions.LiveList:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, LiveListFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.live_list);
                break;
            case NavigationOptions.StageView:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, StageWebFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.stage_view);
                break;
            case NavigationOptions.LiveView:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, LiveWebFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.live_view);
                break;
        }
    }

    public void restoreActionBar() {
        ActionBar actionBar = getActionBar();
        actionBar.setNavigationMode(ActionBar.NAVIGATION_MODE_STANDARD);
        actionBar.setDisplayShowTitleEnabled(true);
        actionBar.setTitle(mTitle);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        if (!mNavigationDrawerFragment.isDrawerOpen()) {
            // Only show items in the action bar relevant to this screen
            // if the drawer is not showing. Otherwise, let the drawer
            // decide what to show in the action bar.
            getMenuInflater().inflate(R.menu.open_l, menu);
            restoreActionBar();
            return true;
        }
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        Intent intent;
        switch (item.getItemId()) {
            case R.id.action_preferences:
                intent = new Intent(this, SettingsActivity.class);
                startActivity(intent);
                return true;
            case R.id.action_connections:
                intent = new Intent(this, ConnectionActivity.class);
                startActivity(intent);
                return true;
            case R.id.action_refresh:
                if (this.mTitle.equals(getString(R.string.service_list))) {
                    ServiceListFragment fragment = (ServiceListFragment)
                            getFragmentManager().findFragmentById(R.id.container);
                    fragment.refreshDisplay();
                } else if (this.mTitle.equals(getString(R.string.live_list)) ) {
                    LiveListFragment fragment = (LiveListFragment)
                            getFragmentManager().findFragmentById(R.id.container);
                    fragment.refreshDisplay();
                }
                return true;
            case R.id.action_blank:
                new BlankDisplayDialog().show(getFragmentManager(), "BlankDialog");
                return true;
            case R.id.action_alert:
                new AlertDisplayDialog().show(getFragmentManager(), "AlertDialog");
                return true;
            case R.id.action_about:
                getFragmentManager().beginTransaction()
                        .replace(R.id.container, AboutFragment.newInstance())
                        .commit();
            default:
                return super.onOptionsItemSelected(item);
        }
    }
}
